# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models

DEFAULT_MONTH_RANGE = 3


class AccOperation(models.Model):
    _inherit = "acc.operation"

    def _qweb_prepare_qcontext(self, view_id, domain):
        values = super()._qweb_prepare_qcontext(view_id, domain)
        operations = self.search(domain)

        # Prepare Values to display in qweb view
        values.update(operations._plan_prepare_values())

        return values

    def _plan_prepare_values(self):
        values = {}
        date_day_start, date_day_end = self.get_last_day("day")
        last_day = date_day_start.strftime("%d %B %Y")
        date_day_start = date_day_start.strftime("%Y-%m-%d")
        date_day_end = date_day_end.strftime("%Y-%m-%d")

        date_week_start, date_week_end = self.get_last_day("week")
        last_week = (
            date_week_start.strftime("%d %B %Y")
            + "-"
            + date_week_end.strftime("%d %B %Y")
        )
        date_week_start = date_week_start.strftime("%Y-%m-%d")
        date_week_end = date_week_end.strftime("%Y-%m-%d")

        date_month_start, date_month_end = self.get_last_day("month")
        last_month = (
            date_month_start.strftime("%d %B %Y")
            + "-"
            + date_month_end.strftime("%d %B %Y")
        )
        date_month_start = date_month_start.strftime("%Y-%m-%d")
        date_month_end = date_month_end.strftime("%Y-%m-%d")

        # range_date = date_start.strftime("%d/%m/%Y") + ' - ' + date_end.strftime("%d/%m/%Y")

        date_semestre_start, date_semestre_end = self.get_last_day("semestre")
        last_semester = (
            date_semestre_start.strftime("%d %B %Y")
            + "-"
            + date_semestre_end.strftime("%d %B %Y")
        )
        date_semestre_start = date_semestre_start.strftime("%Y-%m-%d")
        date_semestre_end = date_semestre_end.strftime("%Y-%m-%d")

        date_year_start, date_year_end = self.get_last_day("year")
        last_year = (
            date_year_start.strftime("%d %B %Y")
            + "- "
            + date_year_end.strftime("%d %B %Y")
        )
        date_year_start = date_year_start.strftime("%Y-%m-%d")
        date_year_end = date_year_end.strftime("%Y-%m-%d")

        data_values = {
            "last_day": last_day,
            "last_week": last_week,
            "last_month": last_month,
            "last_semestre": last_semester,
            "last_year": last_year,
            # 'range_date': range_date,
            "date_day_start": date_day_start,
            "date_day_end": date_day_end,
            "date_week_start": date_week_start,
            "date_week_end": date_week_end,
            "date_month_start": date_month_start,
            "date_month_end": date_month_end,
            "date_semestre_start": date_semestre_start,
            "date_semestre_end": date_semestre_end,
            "date_year_start": date_year_start,
            "date_year_end": date_year_end,
        }

        values["data_values"] = data_values
        return values
